@@ -1,6 +1,9 @@
 import unittest
 import re
 from mavehgvs.patterns.dna import (
+    dna_equal_c,
+    dna_equal_n,
+    dna_equal_gmo,
     dna_sub_c,
     dna_sub_n,
     dna_sub_gmo,
@@ -22,6 +25,108 @@ from mavehgvs.patterns.dna import (
     dna_single_variant,
     dna_multi_variant,
 )
+from . import build_multi_variants
+
+
+class TestDnaEqualC(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.pattern = re.compile(dna_equal_c, flags=re.ASCII)
+
+        cls.valid_strings = [
+            "=",
+            "18=",
+            "10_14=",
+            "122-6=",
+            "*24=",
+            "19+22=",
+            "19+22_88=",
+            "-27+3=",
+        ]
+
+        cls.invalid_strings = ["=22", "(=)", "18(=)"]
+
+    def test_valid_strings(self):
+        for s in self.valid_strings:
+            with self.subTest(s=s):
+                self.assertIsNotNone(
+                    self.pattern.fullmatch(s), msg=f'failed to match "{s}"'
+                )
+
+    def test_invalid_strings(self):
+        for s in self.invalid_strings:
+            with self.subTest(s=s):
+                self.assertIsNone(
+                    self.pattern.fullmatch(s), msg=f'incorrectly matched "{s}"'
+                )
+
+
+class TestDnaEqualN(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.pattern = re.compile(dna_equal_n, flags=re.ASCII)
+
+        cls.valid_strings = ["="]
+
+        cls.invalid_strings = [
+            "=22",
+            "(=)",
+            "18(=)",
+            "-27+3=",
+            "*24=",
+            "18=",
+            "10_14=",
+            "122-6=",
+            "19+22=",
+            "19+22_88=",
+        ]
+
+    def test_valid_strings(self):
+        for s in self.valid_strings:
+            with self.subTest(s=s):
+                self.assertIsNotNone(
+                    self.pattern.fullmatch(s), msg=f'failed to match "{s}"'
+                )
+
+    def test_invalid_strings(self):
+        for s in self.invalid_strings:
+            with self.subTest(s=s):
+                self.assertIsNone(
+                    self.pattern.fullmatch(s), msg=f'incorrectly matched "{s}"'
+                )
+
+
+class TestDnaEqualGMO(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.pattern = re.compile(dna_equal_gmo, flags=re.ASCII)
+
+        cls.valid_strings = ["=", "18=", "10_14="]
+
+        cls.invalid_strings = [
+            "=22",
+            "(=)",
+            "18(=)",
+            "122-6=",
+            "*24=",
+            "19+22=",
+            "19+22_88=",
+            "-27+3=",
+        ]
+
+    def test_valid_strings(self):
+        for s in self.valid_strings:
+            with self.subTest(s=s):
+                self.assertIsNotNone(
+                    self.pattern.fullmatch(s), msg=f'failed to match "{s}"'
+                )
+
+    def test_invalid_strings(self):
+        for s in self.invalid_strings:
+            with self.subTest(s=s):
+                self.assertIsNone(
+                    self.pattern.fullmatch(s), msg=f'incorrectly matched "{s}"'
+                )
 
 
 class TestDnaSubC(unittest.TestCase):
@@ -29,9 +134,9 @@ class TestDnaSubC(unittest.TestCase):
     def setUpClass(cls):
         cls.pattern = re.compile(dna_sub_c, flags=re.ASCII)
 
-        cls.valid_strings = ["48C>A", "=", "122-6T>A", "*24G>C", "19+22A>G", "-27+3T>C"]
+        cls.valid_strings = ["48C>A", "122-6T>A", "*24G>C", "19+22A>G", "-27+3T>C"]
 
-        cls.invalid_strings = ["22g>u", "48C>W", "22=", "122=/T>A"]
+        cls.invalid_strings = ["22g>u", "48C>W", "122=/T>A"]
 
     def test_valid_strings(self):
         for s in self.valid_strings:
@@ -53,16 +158,9 @@ class TestDnaSubN(unittest.TestCase):
     def setUpClass(cls):
         cls.pattern = re.compile(dna_sub_n, flags=re.ASCII)
 
-        cls.valid_strings = ["48C>A", "=", "122-6T>A", "19+22A>G"]
+        cls.valid_strings = ["48C>A", "122-6T>A", "19+22A>G"]
 
-        cls.invalid_strings = [
-            "22g>u",
-            "48C>W",
-            "22=",
-            "122=/T>A",
-            "*24G>C",
-            "-27+3T>C",
-        ]
+        cls.invalid_strings = ["22g>u", "48C>W", "122=/T>A", "*24G>C", "-27+3T>C"]
 
     def test_valid_strings(self):
         for s in self.valid_strings:
@@ -84,7 +182,7 @@ class TestDnaSubGmo(unittest.TestCase):
     def setUpClass(cls):
         cls.pattern = re.compile(dna_sub_gmo, flags=re.ASCII)
 
-        cls.valid_strings = ["48C>A", "="]
+        cls.valid_strings = ["48C>A"]
 
         cls.invalid_strings = ["122-6T>A", "22g>u", "48C>W", "22=", "122=/T>A", "0C>T"]
 
@@ -478,6 +576,8 @@ class TestDnaVariantC(unittest.TestCase):
         cls.valid_strings = [
             "48C>A",
             "=",
+            "22=",
+            "4_6=",
             "122-6T>A",
             "*24G>C",
             "19+22A>G",
@@ -504,7 +604,6 @@ class TestDnaVariantC(unittest.TestCase):
         cls.invalid_strings = [
             "22g>u",
             "48C>W",
-            "22=",
             "122=/T>A",
             "(78+1_79-1)_(124+1_125-1)del",
             "(?_85)_(124_?)del",
@@ -559,9 +658,10 @@ class TestDnaVariantN(unittest.TestCase):
         ]
 
         cls.invalid_strings = [
+            "22=",
+            "1_3=",
             "22g>u",
             "48C>W",
-            "22=",
             "122=/T>A",
             "(78+1_79-1)_(124+1_125-1)del",
             "(?_85)_(124_?)del",
@@ -606,6 +706,8 @@ class TestDnaVariantGmo(unittest.TestCase):
         cls.valid_strings = [
             "48C>A",
             "=",
+            "22=",
+            "1_3=",
             "44del",
             "1_95del",
             "22_24dup",
@@ -632,7 +734,6 @@ class TestDnaVariantGmo(unittest.TestCase):
             "-27+3T>C",
             "22g>u",
             "48C>W",
-            "22=",
             "122=/T>A",
             "(78+1_79-1)_(124+1_125-1)del",
             "(?_85)_(124_?)del",
@@ -699,10 +800,11 @@ class TestDnaSingleVariant(unittest.TestCase):
             "122-6T>A",
         ]
 
+        cls.valid_strings_cgmo_only = ["22=", "4_6="]
+
         cls.invalid_strings = [
             "22g>u",
             "48C>W",
-            "22=",
             "122=/T>A",
             "(78+1_79-1)_(124+1_125-1)del",
             "(?_85)_(124_?)del",
@@ -725,6 +827,13 @@ class TestDnaSingleVariant(unittest.TestCase):
                     self.assertIsNotNone(
                         self.pattern.fullmatch(v), msg=f'failed to match "{v}"'
                     )
+        for p in "cgmo":
+            for s in self.valid_strings_cgmo_only:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.{s}"
+                    self.assertIsNotNone(
+                        self.pattern.fullmatch(v), msg=f'failed to match "{v}"'
+                    )
         for p in "cn":
             for s in self.valid_strings_cn_only:
                 with self.subTest(s=s, p=p):
@@ -748,6 +857,13 @@ class TestDnaSingleVariant(unittest.TestCase):
                     self.assertIsNone(
                         self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
                     )
+        for p in "ngmo":
+            for s in self.valid_strings_c_only:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.{s}"
+                    self.assertIsNone(
+                        self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
+                    )
         for p in "gmo":
             for s in self.valid_strings_cn_only:
                 with self.subTest(s=s, p=p):
@@ -756,7 +872,7 @@ class TestDnaSingleVariant(unittest.TestCase):
                         self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
                     )
         for p in "n":
-            for s in self.valid_strings_c_only:
+            for s in self.valid_strings_cgmo_only:
                 with self.subTest(s=s, p=p):
                     v = f"{p}.{s}"
                     self.assertIsNone(
@@ -765,9 +881,133 @@ class TestDnaSingleVariant(unittest.TestCase):
 
 
 class TestDnaMultiVariant(unittest.TestCase):
-    @unittest.expectedFailure
-    def test_something(self):
-        self.assertEqual(True, False)
+    @classmethod
+    def setUpClass(cls):
+        cls.pattern = re.compile(dna_multi_variant, flags=re.ASCII)
+
+        single_valid_strings = [
+            "48C>A",
+            "=",
+            "44del",
+            "1_95del",
+            "22_24dup",
+            "77dup",
+            "234_235insT",
+            "84_85insCTG",
+            "22delinsAACG",
+            "83_85delinsT",
+        ]
+
+        single_valid_strings_c_only = [
+            "*788delinsA",
+            "-25+1_-25+3dup",
+            "*17dup",
+            "-25+1_-25+3del",
+            "*17del",
+            "*24G>C",
+            "-27+3T>C",
+        ]
+
+        single_valid_strings_cn_only = [
+            "43-6_595+12delinsCTT",
+            "99+6_99+7insA",
+            "101+1_101+7dup",
+            "78+5_78+10del",
+            "19+22A>G",
+            "122-6T>A",
+        ]
+
+        single_valid_strings_cgmo_only = ["22=", "4_6="]
+
+        single_invalid_strings = [
+            "22g>u",
+            "48C>W",
+            "122=/T>A",
+            "(78+1_79-1)_(124+1_125-1)del",
+            "(?_85)_(124_?)del",
+            "122=/del",
+            "(78+1_79-1)_(124+1_125-1)dup",
+            "(?_85)_(124_?)dup",
+            "122_125=//dup",
+            "84_85ins100_125",
+            "234_235ins(10)",
+            "234_235ins(?)",
+            "84_85delinsAAN",
+            "234delinsW",
+        ]
+
+        cls.valid_strings, cls.invalid_strings = build_multi_variants(
+            single_valid_strings, single_invalid_strings
+        )
+        cls.valid_strings_c_only, cls.invalid_strings_ngmo = build_multi_variants(
+            single_valid_strings_c_only, single_valid_strings_c_only
+        )
+        cls.valid_strings_cn_only, cls.invalid_strings_gmo = build_multi_variants(
+            single_valid_strings_cn_only, single_valid_strings_cn_only
+        )
+        cls.valid_strings_cgmo_only, cls.invalid_strings_n = build_multi_variants(
+            single_valid_strings_cgmo_only, single_valid_strings_cgmo_only
+        )
+
+    def test_valid_strings(self):
+        for p in "cngmo":
+            for s in self.valid_strings:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNotNone(
+                        self.pattern.fullmatch(v), msg=f'failed to match "{v}"'
+                    )
+        for p in "cgmo":
+            for s in self.valid_strings_cgmo_only:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNotNone(
+                        self.pattern.fullmatch(v), msg=f'failed to match "{v}"'
+                    )
+        for p in "cn":
+            for s in self.valid_strings_cn_only:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNotNone(
+                        self.pattern.fullmatch(v), msg=f'failed to match "{v}"'
+                    )
+        for p in "c":
+            for s in self.valid_strings_c_only:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNotNone(
+                        self.pattern.fullmatch(v), msg=f'failed to match "{v}"'
+                    )
+
+    def test_invalid_strings(self):
+        for p in "cngmo":
+            for s in self.invalid_strings:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNone(
+                        self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
+                    )
+        for p in "ngmo":
+            for s in self.invalid_strings_ngmo:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNone(
+                        self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
+                    )
+        for p in "gmo":
+            for s in self.invalid_strings_gmo:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNone(
+                        self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
+                    )
+        for p in "n":
+            for s in self.invalid_strings_n:
+                with self.subTest(s=s, p=p):
+                    v = f"{p}.[{s}]"
+                    self.assertIsNone(
+                        self.pattern.fullmatch(v), msg=f'incorrectly matched "{v}"'
+                    )
 
 
 if __name__ == "__main__":
